package examples.hibernate.domain;

import java.text.SimpleDateFormat;
import java.util.Date;

public class Event {
    public enum EventType { CLASS, PARTY, MEETING }

    private static int eventCount;           // transient property
    private transient String startAsString;  // transient property

    private String organizer;                // transient property

    private String name;                     // persistent property
    private boolean confirmed;               // persistent property

    private EventType type;                  // enum persisted as String in database

    private Date start;                      // persistent property

    private String extraInfo;                // persistent property persisted as a CLOB

    protected Event() { }

    public Event(String name, Date start, EventType type) {
	eventCount++;
	setName(name);
	setConfirmed(false);
	setType(type);
	setStart(start);
	setExtraInfo(extraInfo);
    }

    public static long getEventCount() {
	return eventCount;
    }

    public String getStartAsString() {
	if (startAsString == null)
		startAsString = SimpleDateFormat.getDateTimeInstance().format(start);
	return startAsString;
    }

    public String getOrganizer() {
	return organizer;
    }

    public void setOrganizer(String organizer) {
	this.organizer = organizer;
    }

    public String getName() {
	return name;
    }

    public void setName(String name) {
	this.name = name;
    }

    public boolean isConfirmed() {
	return confirmed;
    }

    public void setConfirmed(boolean confirmed) {
	this.confirmed = confirmed;
    }

    public EventType getType() {
	return type;
    }

    public void setType(EventType type) {
	this.type = type;
    }

    public Date getStart() {
	return new Date(start.getTime());
    }

    public void setStart(Date date) {
	this.start = date;
    }

    public String getExtraInfo() {
	return extraInfo;
    }

    public void setExtraInfo(String info) {
	this.extraInfo= info;
    }

    public String toString() {
	StringBuilder sb = new StringBuilder("Event: ").append(name)
						      .append("\t\t(")
						      .append(getStartAsString())
						      .append(")");
	sb.append("\nType: ").append(type);
	if (organizer != null) sb.append("\t\tOrganizer: ").append(organizer);
	if (organizer != null) sb.append("\nExtraInfo:\n").append(extraInfo);
	return sb.toString();
    }

}
